function fredholm2_nonlin_NR_demo1
clear all;
close all;
%
%  Solution to a Nonlinear Fredholm Equation of the Second Kind
%
%  The Fredholm Equations have five parameters
%
%  the lower limit of integration, a
%  the lower limit of integration, b
%  the constant prefactor outside the integral, lam
%  the function outside the integral, f, given in a function at the bottom of this file
%  the kernel, kernelorig, given in a function at the bottom of this file
%  This code gives the numeric solution to a=0, b=1, lam=-1, f=e=^x and K=sin(phi)
%
%  Author:  David Keffer, University of Tennessee, Department of Chemical Engineering
%
clf
a = 0.0;
b = 1.0;
lam = -1.0e-0;
%
%  set up a grid of x values
%
xstart = a;
xf = b;
%
%  USING NEWTON RAPHSON METHOD
%
ninterval = 50;
npoints = ninterval+1;
dx = (xf-xstart)/ninterval;
x = zeros(npoints,1);
for i = 1:1:npoints
   x(i) = xstart + (i-1)*dx;
end
maxit = 100;
phi = zeros(npoints,maxit);
%
%  initialize phi(:,1)
%
for i = 1:1:npoints
   phi(i,1) = f(x(i));
end
%plot (x,phi(:,1),'k-'), xlabel( 'x' ), ylabel ( 'phi' );
%hold on;
%
% dimension vectors
%
Jac = zeros(npoints,npoints);
R = zeros(npoints, 1);
dphi = zeros(npoints,1);
%
%  Newton raphson convergence parameters
%
err = 100.0;
tol = 1.0e-8;
icount = 1;
%
dxh = 0.5*dx;
fac1 = lam*dxh;
fac2 = 2*fac1;
while (err > tol & icount <= maxit)
   icount = icount + 1;
   %
   % create residual vector
   %
   for i = 1:1:npoints
      R(i) = -phi(i,icount-1) + f(x(i));
      for j = 2:1:npoints
         jm1 = j-1;
      	side1 = kern(phi(jm1,icount-1),x(i),x(jm1));
      	side2 = kern(phi(j,icount-1),x(i),x(j));
      	Areatrap = fac1*(side1 + side2);
         R(i) = R(i) + Areatrap;
      end
   end
   %
   % create Jacobian
   %
   for i = 1:1:npoints
      for j = 1:1:npoints
         if (i == 1)
            if (j == 1)
               Jac(i,j) = -1.0;
            else
               Jac(i,j) = 0.0;
            end
         else
            if (j == 1)
               Jac(i,j) = fac1*dkern(phi(j,icount-1),x(i),x(j));
            elseif (j == i)
               Jac(i,j) = -1.0 + fac2*dkern(phi(j,icount-1),x(i),x(j));
            elseif (j == npoints)
               Jac(i,j) = fac1*dkern(phi(j,icount-1),x(i),x(j));
            else
               Jac(i,j) = fac2*dkern(phi(j,icount-1),x(i),x(j));
            end
         end
      end
   end
   %
   %  Complete Newton Raphson Step
   %
   invJac = inv(Jac);
   dphi = -invJac*R;
   phi(:,icount) = phi(:,icount-1) + dphi(:);
   err = sqrt(sum(R.*R)/npoints);
   %
   % plot at each iteration
   %
   iplot =1;
   if ( iplot == 1 )
      jj = icount;
		if (jj==1)
     		plot (x,phi(:,jj),'k-'), xlabel( 'x' ), ylabel ( 'phi' )
  		elseif (jj==2)
     		plot (x,phi(:,1),'k-'), xlabel( 'x' ), ylabel ( 'phi' )
         hold on;
     		plot (x,phi(:,jj),'r-'), xlabel( 'x' ), ylabel ( 'phi' )
  		elseif (jj==3)
     		plot (x,phi(:,jj),'b-'), xlabel( 'x' ), ylabel ( 'phi' )
  		elseif (jj==4)
     		plot (x,phi(:,jj),'g-'), xlabel( 'x' ), ylabel ( 'phi' )
  		elseif (jj==5)
     		plot (x,phi(:,jj),'m-'), xlabel( 'x' ), ylabel ( 'phi' )
  		elseif (jj==6)
     		plot (x,phi(:,jj),'k:'), xlabel( 'x' ), ylabel ( 'phi' )
  		elseif (jj==7)
     		plot (x,phi(:,jj),'r:'), xlabel( 'x' ), ylabel ( 'phi' )
  		elseif (jj==8)
     		plot (x,phi(:,jj),'b:'), xlabel( 'x' ), ylabel ( 'phi' )
  		elseif (jj==9)
     		plot (x,phi(:,jj),'g:'), xlabel( 'x' ), ylabel ( 'phi' )
  		elseif (jj==10)
     		plot (x,phi(:,jj),'m:'), xlabel( 'x' ), ylabel ( 'phi' )
 		else
     		plot (x,phi(:,jj),'k-'), xlabel( 'x' ), ylabel ( 'phi' )
		end
		hold on;
   end      
end
hold off;
figure(2)
jj = icount;
plot (x,phi(:,jj),'k-'), xlabel( 'x' ), ylabel ( 'phi' )
title('converged solution');
format long e
phi(:,icount)
fprintf(1, 'It took %i iterations to reach an error of %e \n', icount-1, err);


function y = f(x)
y = exp(x);

function z = kern(phi,x,y)
z = exp(x-y)*phi;

function z = dkern(phi,x,y)
z = exp(x-y);


