function volterra2_linear
%
%  Solution to a Volterra Equation of the Second Kind
%
%  The Volterra Equations have four parameters
%
%  the lower limit of integration, a
%  the constant prefactor outside the integral, lam
%  the function outside the integral, f, given in a function at the bottom of this file
%  the kernel, kernelorig, given in a function at the bottom of this file
%
%  This code gives teh numeric solution to a=0, lam=-1, f=e=^x and N=e^(x-y)
%
%  Author:  David Keffer, University of Tennessee, Department of Chemical Engineering
%
close all;

time_01 = cputime;
a = 0;
lam = -1;
%
%  set up a grid of x values
%
xstart = 0.0;
xf = 1.0;
%
%  let's run different runs where we change the step size
%  just to see the effect
%
nruns = 10;
nintervals=[2;4;8;16;32;64;128;256;512;1024]';
npoints = nintervals+1;
%
for jj = 1:1:nruns
   %
   %  set up the x grid
   %
   ninterval = nintervals(jj);
   npoints = ninterval+1;
   phi = zeros(npoints,1)';
   dx = (xf-xstart)/ninterval;
	x = zeros(npoints,1);
	for i = 1:1:npoints
   	x(i) = xstart + (i-1)*dx;
	end
	%
	%  calculate and plot purely analytic phi
   %
   amat = zeros(npoints,npoints);
	bnum = zeros(npoints,1);
	fac = lam*dx;
	for i = 1:1:npoints
   	xi = x(i);
   	if (i == 1)
      	amat(i,i) = 1.0;
   	else
   		amat(i,i) = 1.0  - fac*0.5*kernelorig(xi,xi) ;
   	end
   	bnum(i) = f(xi);
   	for j = 1:1:npoints
      	yj = x(j);
      	if (j < i)
         	if (j == 1) 
            	amat(i,j) = - fac*0.5*kernelorig(xi,yj);
         	else
            	amat(i,j) = -fac*kernelorig(xi,yj);
         	end
      	end
   	end
	end
	amatinv = inv(amat);
	phi = amatinv*bnum;
   %
   % plot
   %
	if (jj==1)
     plot (x,phi(:),'k-'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (jj==2)
     plot (x,phi(:),'r-'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (jj==3)
     plot (x,phi(:),'b-'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (jj==4)
     plot (x,phi(:),'g-'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (jj==5)
     plot (x,phi(:),'m-'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (jj==6)
     plot (x,phi(:),'k:'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (jj==7)
     plot (x,phi(:),'r:'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (jj==8)
     plot (x,phi(:),'b:'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (jj==9)
     plot (x,phi(:),'g:'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (jj==10)
     plot (x,phi(:),'m:'), xlabel( 'x' ), ylabel ( 'phi' )
 	else
     plot (x,phi(:),'k-'), xlabel( 'x' ), ylabel ( 'phi' )
	end
	hold on
	fprintf (1,'FINISHED CALCULATING THE %2i RUN where nintervals = %10f \n', jj, ninterval);
end
hold off

function y = f(x)
y = exp(x);

function y = kernelorig(x,y)
y = exp(x-y);
